| Title: | Insert Manifestation and Author Blocks in R Scripts |
|---|---|
| Description: | Provides an RStudio addin and function to insert a customizable "manifestation block" and author metadata into R scripts. The block includes intention-setting messages, script name, purpose, author information, creation/modification dates, citation instructions, and notes. User defaults can be preloaded from a configuration file to minimize repetition. |
| Authors: | Jyotirmoy Das [aut, cre] (ORCID: <https://orcid.org/0000-0002-5649-4658>) |
| Maintainer: | Jyotirmoy Das <[email protected]> |
| License: | GPL-3 | file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-15 08:35:51 UTC |
| Source: | https://github.com/JD2112/jyotirmoymanifest |
Insert Manifestation Header (smart, with config + prompt)
insert_manifestation( script_name = NULL, purpose = NULL, author = NULL, email = NULL, citation = NULL, notes = NULL, save_profile = FALSE )insert_manifestation( script_name = NULL, purpose = NULL, author = NULL, email = NULL, citation = NULL, notes = NULL, save_profile = FALSE )
script_name |
Optional name of the script |
purpose |
Script purpose |
author |
Author name |
email |
Contact email |
citation |
Preferred citation |
notes |
Additional notes |
save_profile |
Logical. If TRUE, saves the inputs to ~/.manifest_profile.R |